@@ -1,8 +1,8 @@
 package WebService::GData::Node::GD::Rating;
 use WebService::GData::Node::GD;
 
-set_xml_meta(
-   attributes=>[qw(min max numRaters average value)],
+set_meta(
+   attributes=>[qw(min max numRaters average value rel)],
    is_parent=>0
 );
 
