@@ -1,8 +1,8 @@
 package WebService::GData::Node::GML::Point;
 use WebService::GData::Node::GML;
 
-set_xml_meta(
-  tag_name=>'Point'
+set_meta(
+  node_name=>'Point'
 ); 
 
 
