@@ -1,8 +1,8 @@
 package WebService::GData::Node::Media::Content;
 use WebService::GData::Node::Media;
 
-set_xml_meta(
-    attributes=>[qw(url type medium isDefault expression duration),'yt:format'],
+set_meta(
+    attributes=>[qw(url type medium isDefault expression duration)],
     is_parent =>0
 );
 
