@@ -1,8 +1,8 @@
 package WebService::GData::Node::Media::Credit;
 use WebService::GData::Node::Media;
 
-set_xml_meta(
-    attributes=>['role','yt:type','scheme']
+set_meta(
+    attributes=>['role','scheme']
 );
 
 1;
