@@ -1,7 +1,7 @@
 package WebService::GData::Node::Media::Thumbnail;
 use WebService::GData::Node::Media;
 
-set_xml_meta(
+set_meta(
     attributes=>[qw(url height width time)],
     is_parent=>0
 );
