@@ -1,7 +1,7 @@
 package WebService::GData::YouTube::YT::AccessControl;
 use WebService::GData::YouTube::YT;
 
-set_xml_meta(
+set_meta(
   attributes=>[qw(action permission)],
   is_parent =>0
 );
