@@ -1,7 +1,7 @@
 package WebService::GData::YouTube::YT::Duration;
 use WebService::GData::YouTube::YT;
 
-set_xml_meta(
+set_meta(
   attributes=>[qw(seconds)],
   is_parent =>0
 );
