@@ -1,7 +1,7 @@
 package WebService::GData::YouTube::YT::Incomplete;
 use WebService::GData::YouTube::YT;
 
-set_xml_meta(
+set_meta(
   is_parent =>0
 );
 
