@@ -1,4 +1,4 @@
 package WebService::GData::YouTube::YT::LastName;
-use WebService::GData::YouTube::Node;
+use WebService::GData::YouTube::YT;
 
 1;
\ No newline at end of file
