@@ -1,7 +1,7 @@
 package WebService::GData::YouTube::YT::Rating;
 use WebService::GData::YouTube::YT;
 
-set_xml_meta(
+set_meta(
     attributes=>[qw(numLikes numDislikes value)],
     is_parent=>0,
 );
