@@ -1,7 +1,7 @@
 package WebService::GData::YouTube::YT::State;
 use WebService::GData::YouTube::YT;
 
-set_xml_meta(
+set_meta(
   attributes=>[qw(name reasonCode helpUrl)]
 );
 
